'use strict';

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _mocha = require('mocha');

var _mocha2 = _interopRequireDefault(_mocha);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class WebpackMochaPlugin {
  constructor(options) {
    this.options = options;

    const testDir = options.testDir ? options.testDir : 'test';
    const pattern = new RegExp(options.pattern ? options.pattern : '.js');

    this.mocha = new _mocha2.default({ reporter: 'list' });

    _fs2.default.readdirSync(testDir).filter(file => pattern.test(file)).forEach(file => this.mocha.addFile(_path2.default.join(options.testDir, file)));

    this.apply = this.apply.bind(this);
    this.handleFailure = this.handleFailure.bind(this);
  }

  handleFailure(compilation, test, err) {
    const error = new Error(`test ${test.title}\n${JSON.stringify(err)}`);
    if (this.options.emitWarn) {
      compilation.warnings.push(error);
    } else {
      compilation.errors.push(error);
    }
  }

  apply(compiler) {
    compiler.plugin('compilation', compilation => {
      this.mocha.run().on('fail', (test, err) => this.handleFailure(compilation, test, err));
    });
  }
}

module.exports = WebpackMochaPlugin;
